<?php
/**
 * Moony - the PHP simplistic framework
 *
 * @package   Moony
 * @author    YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @link      http://moony.sourceforge.jp/
 * @copyright 2005-2007 YAMAOKA Hiroyuki
 * @license   http://opensource.org/licenses/bsd-license.php The BSD License
 */

/**
 * レジストリクラスです。値の参照を保存します。
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @access public
 */
class Moony_Registry
{
    /**
     * 保存されている値の連想配列
     * @var array
     */
    var $entries = array();

    /**
     * 値の参照を保存します。
     *
     * @access public
     * @static
     * @param string $name 保存する値の名称
     * @param mixed $value 保存する値
     */
    function save($name, &$value)
    {
        $registry =& Moony_Registry::_getInstance();
        $registry->entries[$name] = &$value;
    }

    /**
     * 保存されていた値の参照を取得します。
     * 指定された名称の値が保存されていない場合、nullを返します。
     *
     * @access public
     * @static
     * @param string $name 保存されている値の名称
     * @return mixed 保存されていた値の参照
     */
    function &get($name)
    {
        $value = null;
        $registry =& Moony_Registry::_getInstance();
        if (array_key_exists($name, $registry->entries)) {
            $value =& $registry->entries[$name];
        }
        return $value;
    }

    /**
     * 指定された名称の値が保存されているかどうか調べます。
     *
     * @access public
     * @static
     * @param string $name 値の名称
     * @return bool 値が保存されているかどうか
     */
    function exists($name)
    {
        $registry =& Moony_Registry::_getInstance();
        return array_key_exists($name, $registry->entries);
    }

    /**
     * このクラスのsingletonインスタンスを返します。
     *
     * @access protected
     * @static
     * @return object このクラスのsingletonインスタンス
     */
    function &_getInstance()
    {
        static $instance = null;
        if (is_null($instance)) {
            $instance = new Moony_Registry();
        }
        return $instance;
    }
}
?>
